<?php
/**
 * Plugin Name: Floating Action Buttons
 * Plugin URI: https://wordpress.org/plugins/floating-action-buttons/
 * Description: Let your store help your customers like a real person with your own completely customizable search.
 * Version:  0.9.1
 * @package   Floating Action Buttons
 * @author    QuantumCloud
 * Author: QunatumCloud
 * Author URI: https://www.quantumcloud.com/
 * Requires at least: 4.6
 * Tested up to: 5.0.0
 * Text Domain: floating-action-button
 * Domain Path: /lang/
 * License: GPL2
 */


if (!defined('ABSPATH')) exit; // Exit if accessed directly

define('QC_FLOATING_ACTION_BUTTON_VERSION', '2.0.0');
define('QC_FLOATING_ACTION_BUTTON_PLUGIN_DIR_PATH', basename(plugin_dir_path(__FILE__)));
define('QC_FLOATING_ACTION_BUTTON_PLUGIN_URL', plugin_dir_url(__FILE__));
define('QC_FLOATING_ACTION_BUTTON_IMG_URL', QC_FLOATING_ACTION_BUTTON_PLUGIN_URL . "images/");
define('QC_FLOATING_ACTION_BUTTON_IMG_ABSOLUTE_PATH', plugin_dir_path(__FILE__) . "images");
require_once("qc-fab-functions.php");

/**
 * Main Class.
 */
class WC_FLOATING_ACTION_BUTTONS
{

    private $id = 'floating-action-button';

    private static $instance;

    /**
     *  Get Instance creates a singleton class that's cached to stop duplicate instances
     */
    public static function get_instance()
    {
        if (!self::$instance) {
            self::$instance = new self();
            self::$instance->init();
        }
        return self::$instance;
    }

    /**
     *  Construct empty on purpose
     */

    private function __construct()
    {
    }

    /**
     *  Init behaves like, and replaces, construct
     */

    public function init()
    {

        $this->general_includes();

        add_action('admin_menu', array($this, 'admin_menu'));

        add_action('widgets_init', array($this, 'register_widgets'));

        if ((!empty($_GET["page"])) && ($_GET["page"] == "floating-action-button")) {

            add_action('admin_init', array($this, 'floating_action_buttons_save_options'));
        }

        add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));

        if (!is_admin()) {

            add_action('wp_enqueue_scripts', array($this, 'frontend_scripts'));
        }


    }


    /**
     * Add a submenu item to the menu
     */
    public function admin_menu()
    {

        add_menu_page( 
            'floating-action-buttons', 
            'Floating Action Buttons', 
            'manage_options', 
            $this->id, 
            array( $this, 'admin_page' ),
            'dashicons-dashboard',
            20 
        );


        /*
        add_submenu_page('floating-action-buttons',
            __('Floating Action Buttons', 'floating-action-buttons'),
            __('Floating Action Buttons', 'floating-action-buttons'),
            'manage_options',
            'floating-action-buttons',
            array($this, 'admin_page'));
        */


    }

    /**
     * Include backend required files.
     *
     * @return void
     */
    public function backend_includes()
    {
       


    }

    /**
     * Include general required files.
     *
     * @return void
     */
    public function general_includes(){


    }


    /**
     * Include admin scripts
     */
    public function admin_scripts($hook)
    {
        global $wp_scripts;

        $suffix = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';

        if (((!empty($_GET["page"])) && ($_GET["page"] == "floating-action-button")) || ($hook == "widgets.php")) {

            wp_enqueue_script('jquery');

            wp_register_style('qc-fab-backend-style', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/admin-style.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-backend-style');

            wp_register_style('qc-fab-font-awesome', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/font-awesome.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-font-awesome');

            wp_register_style('qc-fab-font-awesome-animation', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/font-awesome-animation.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-font-awesome-animation');

            wp_register_style('qc-fab-sweetalert2-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/sweetalert2.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-sweetalert2-css');

            wp_register_style('qc-fab-select2-style', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/select2.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-select2-style');

            wp_register_style('qc-fab-tabs', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-fab-tabs.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-tabs');

            wp_register_script('qc-fab-cbpFWTabs', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/cbpFWTabs.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('qc-fab-cbpFWTabs');

            wp_register_script('qc-fab-sweetatert2-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/sweetalert2.min.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('qc-fab-sweetatert2-js');

            wp_register_script('qc-fab-modernizr-custom', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/modernizr.custom.js', basename(__FILE__)), array(), true);
            wp_enqueue_script('qc-fab-modernizr-custom');

            wp_register_script('qc-fab-jquery-grideditor', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.grideditor.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('qc-fab-jquery-grideditor');

            wp_register_script('qc-fab-select2', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/select2.full.min.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('qc-fab-select2');


            wp_register_script('qc-fab-bootstrap-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/bootstrap.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('qc-fab-bootstrap-js');

            wp_register_style('qc-fab-qc-layout', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-layout.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-qc-layout');

            wp_register_style('qc-fab-bootstrap-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/bootstrap.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-bootstrap-css');

            wp_register_script('qc-fab-repeatable', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.repeatable.js', basename(__FILE__)), array('jquery'));
            wp_enqueue_script('qc-fab-repeatable');

            wp_register_script('qc-fab-admin', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/qc-fab-admin.js', basename(__FILE__)), array('jquery'), true);
            wp_enqueue_script('qc-fab-admin');

          

            wp_localize_script('qc-fab-admin', 'ajax_object',
                array('ajax_url' => admin_url('admin-ajax.php')));

            wp_localize_script('qc-fab-admin', 'plugins_url', array(
                'pluginsurl' => QC_FLOATING_ACTION_BUTTON_IMG_URL,
            ));

            // WordPress  Media library
            wp_enqueue_media();

        }

    }


    public function frontend_scripts()
    {
        global  $wp_scripts;

       

        $qc_fab_params = array(
            'shop_url' => '',
            'qc_fab_pop_up_form_effect' => get_option("qc_floating_action_button_form_animation"),
            'qc_floating_action_button_mode' => get_option("qc_floating_action_button_mode"),
            'position_x' => get_option('position_x'),
            'position_y' => get_option('position_y'),
            'position_x_unit' => get_option('position_x_unit'),
            'position_y_unit' => get_option('position_y_unit'),
            'qc_fab_floating_action_button_disable_icon_animation' => get_option('qc_fab_floating_action_button_disable_icon_animation'),
            'qc_fab_floating_action_button_disable_notification_mobile' => get_option('qc_fab_floating_action_button_disable_notification_mobile'),
            'qc_fab_notifications' => json_encode(array(
                get_option('qc_fab_message_one'),
                get_option('qc_fab_message_two')
            ))
        );

        wp_register_script('classie-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/recomended-prod/classie.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('classie-js');


        wp_register_script('dynamics-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/recomended-prod/dynamics.min.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('dynamics-js');

        wp_register_script('slimscroll-js', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.slimscroll.min.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('slimscroll-js');


        wp_register_script('animatedModal.min', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/animatedModal.min.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('animatedModal.min');


        wp_register_script('jquery-cookie', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/jquery.cookie.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('jquery-cookie');

        wp_register_script('qc-fab-typed', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/qc-fab-typed.js', basename(__FILE__)), array('jquery'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('qc-fab-typed');

        wp_register_script('qc-fab-frontend', plugins_url(basename(plugin_dir_path(__FILE__)) . '/js/qc-fab-frontend.js', basename(__FILE__)), array('jquery', 'jquery-cookie'), QC_FLOATING_ACTION_BUTTON_VERSION, true);
        wp_enqueue_script('qc-fab-frontend');


        wp_localize_script('qc-fab-frontend', 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php'), 'image_path' => QC_FLOATING_ACTION_BUTTON_IMG_URL));


        wp_register_style('qc-layout', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-layout.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
        wp_enqueue_style('qc-layout');


        wp_register_style('animate-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/animate.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
        wp_enqueue_style('animate-css');


        wp_register_style('animatemodal-min-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/animatemodal.min.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
        wp_enqueue_style('animatemodal-min-css');

        wp_register_style('qc-fab-frontend', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/frontend-style.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
        wp_enqueue_style('qc-fab-frontend');

        wp_register_style('qc-fab-sell-notification-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/qc-fab-sell-notification.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
        wp_enqueue_style('qc-fab-sell-notification-css');
        
        if ( get_option('qc_floating_action_button_mode') == 'vertical') {
            //Tooltip for pinball
            wp_register_style('tooltip-pinball-css', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/tooltip-pinball.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('tooltip-pinball-css');
            wp_register_style('qc-fab-template', plugins_url(basename(plugin_dir_path(__FILE__)) . '/css/pinball.css', basename(__FILE__)), '', QC_FLOATING_ACTION_BUTTON_VERSION, 'screen');
            wp_enqueue_style('qc-fab-template');
        }
        wp_localize_script('qc-fab-frontend', 'qc_fab_params', $qc_fab_params);

    }

    public function register_widgets()
    {


    }


    /**
     * Render the admin page
     */
    public function admin_page()
    {

        $action = 'admin.php?page=floating-action-button'; ?>
        <div class="wrap">
            <h1 style="display:none">Floating Action Buttons Pro</h1>
        </div>
        <div class="qc-fab-wrap">
            <div class="icon32"><br>
            </div>
            <form action="<?php echo esc_attr($action); ?>" method="POST" enctype="multipart/form-data">
                <div class="container form-container">
                    <div class="row qc-fab-control-panel-header">

                        <div class="col-sm-6">
                            <h2><?php echo __('Floating Action Buttons', 'floating-action-button'); ?></h2>
                        </div>
                        <div class="col-sm-6 text-right qc-fab-version">
                            <p><a target="_blank" href="https://www.quantumcloud.com/"><?php _e('Floating Action Buttons is a project by Web Design Company QuantumCloud', 'floating-action-button'); ?></a></p>
                        </div>
                    </div>
                    <div class="row qc-fab-control-panel-reset-header">
                        <div class="text-left col-sm-3 col-sm-offset-3 ">
                            <input type="button" class="btn btn-warning submit-button"
                                   id="qc_fab-reset-options-default"
                                   value="<?php _e('Reset all options to Default', 'floating-action-button'); ?>"/>
                        </div>
                        <div class="text-right col-sm-6 ">
                            <input type="hidden" name="action" value="<?php echo esc_attr('qc_fab-submitted', 'floating-action-button'); ?>"/>
                            <input type="submit" class="btn btn-primary submit-button" name="submit"
                                   id="submit" value="<?php _e('Save Settings', 'floating-action-button'); ?>"/>
                        </div>
                    </div>
                    <!--qc-fab-control-panel-header-->
                    <section class="qc-fab-tab-container-inner">
                        <div class="tabs-qc-fab tabs-qc-fab-style-flip">
                            <nav>
                                <ul>
                                    <li><a href="#section-flip-1"><i class="fa fa-toggle-on"></i><span> <strong><?php _e('GENERAL SETTINGS', 'floating-action-button'); ?></strong></span></a>
                                    </li>
                                    <li><a href="#section-flip-2"><i class="fa fa-telegram"></i><span> <?php _e('CUSTOM ICONS', 'floating-action-button'); ?> </span></a></li>
                                    <li><a href="#section-flip-3"><i class="fa fa-gear faa-spin animated"></i><span> <?php _e('ICONS & THEME', 'floating-action-button'); ?></span></a></li>
                                    <li><a href="#section-flip-4"><i class="fa fa-bell"></i><span> <?php _e('MESSAGE CENTER', 'floating-action-button'); ?></span></a></li>
                                    <li><a href="#section-flip-7"><i class="fa fa-language"></i><span> <?php _e('LANGUAGE CENTER', 'floating-action-button'); ?></span></a></li>
                                    <li><a href="#section-flip-8"><i class="fa fa-code"></i><span> <?php _e('Custom CSS', 'floating-action-button'); ?></span></a>
                                    </li>
                                </ul>
                            </nav>
                            <div class="content-wrap">
                                <section id="section-flip-1" class="content-current">
                                    <table class="table table-bordered striped">
                                        <tbody>
                                        <tr>
                                            <td><p class="qc-opt-title-font"><?php _e('Floating Action Button Mode', 'floating-action-button'); ?></p>
                                                <select class="qc_fab_select2_other qc-opt-dcs-font qc_floating_action_button_mode"
                                                        id="qc_floating_action_button_mode"
                                                        name="qc_floating_action_button_mode">
                                                    <option value="<?php echo get_option('qc_floating_action_button_mode'); ?>"
                                                            selected="selected">
                                                        <?php
                                                        if (get_option('qc_floating_action_button_mode') == 'vertical') {
                                                            //echo "";
                                                            _e('Vertical Balls', 'floating-action-button');
                                                        }
                                                        ?>
                                                    </option>
                                                    <option value="<?php echo esc_attr('vertical', 'floating-action-button'); ?>"><?php _e('Vertical Balls', 'floating-action-button'); ?></option>
                                                </select></td>
                                        </tr>
                                        <tr>
                                            <td><p class="qc-opt-title-font"><?php _e('Disable Floating Action Button', 'floating-action-button'); ?> </p>
                                                <div class="cxsc-settings-blocks">
                                                    <input id="qc_floating_action_button_disable" type="checkbox" name="qc_floating_action_button_disable"
                                                           value="<?php echo esc_attr('1', 'floating-action-button'); ?>" <?php echo(get_option('qc_floating_action_button_disable') == '' ? 'checked' : ''); ?>>
                                                    <label for="qc_floating_action_button_disable"><?php _e('Disable floating action button to load', 'floating-action-button'); ?> </label>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td><p class="qc-opt-title-font"> <?php _e('This animation will appear when you click
                                                    floating action button icon on bottom
                                                    right and close popup form', 'floating-action-button'); ?> </p>
                                                <div class="cxsc-settings-blocks">
                                                    <fieldset>
                                                        <select class="qc_fab_select2_other" name="qc_floating_action_button_form_animation">
                                                            <option value="<?php echo get_option('qc_floating_action_button_form_animation'); ?>" selected="selected" ><?php echo get_option('qc_floating_action_button_form_animation'); ?> </option>
                                                            <optgroup label="Attention Seekers">
                                                                <option value="bounce">bounce</option>
                                                                <option value="flash">flash</option>
                                                                <option value="pulse">pulse</option>
                                                                <option value="rubberBand">rubberBand</option>
                                                                <option value="shake">shake</option>
                                                                <option value="swing">swing</option>
                                                                <option value="tada">tada</option>
                                                                <option value="wobble">wobble</option>
                                                                <option value="jello">jello</option>
                                                            </optgroup>
                                                            <optgroup label="Bouncing Entrances">
                                                                <option value="bounceIn">bounceIn</option>
                                                                <option value="bounceInDown">bounceInDown</option>
                                                                <option value="bounceInLeft">bounceInLeft</option>
                                                                <option value="bounceInRight">bounceInRight</option>
                                                                <option value="bounceInUp">bounceInUp</option>
                                                            </optgroup>
                                                            <optgroup label="Bouncing Exits">
                                                                <option value="bounceOut">bounceOut</option>
                                                                <option value="bounceOutDown">bounceOutDown</option>
                                                                <option value="bounceOutLeft">bounceOutLeft</option>
                                                                <option value="bounceOutRight">bounceOutRight</option>
                                                                <option value="bounceOutUp">bounceOutUp</option>
                                                            </optgroup>
                                                            <optgroup label="Fading Entrances">
                                                                <option value="fadeIn">fadeIn</option>
                                                                <option value="fadeInDown">fadeInDown</option>
                                                                <option value="fadeInDownBig">fadeInDownBig</option>
                                                                <option value="fadeInLeft">fadeInLeft</option>
                                                                <option value="fadeInLeftBig">fadeInLeftBig</option>
                                                                <option value="fadeInRight">fadeInRight</option>
                                                                <option value="fadeInRightBig">fadeInRightBig</option>
                                                                <option value="fadeInUp">fadeInUp</option>
                                                                <option value="fadeInUpBig">fadeInUpBig</option>
                                                            </optgroup>
                                                            <optgroup label="Fading Exits">
                                                                <option value="fadeOut">fadeOut</option>
                                                                <option value="fadeOutDown">fadeOutDown</option>
                                                                <option value="fadeOutDownBig">fadeOutDownBig</option>
                                                                <option value="fadeOutLeft">fadeOutLeft</option>
                                                                <option value="fadeOutLeftBig">fadeOutLeftBig</option>
                                                                <option value="fadeOutRight">fadeOutRight</option>
                                                                <option value="fadeOutRightBig">fadeOutRightBig</option>
                                                                <option value="fadeOutUp">fadeOutUp</option>
                                                                <option value="fadeOutUpBig">fadeOutUpBig</option>
                                                            </optgroup>
                                                            <optgroup label="Flippers">
                                                                <option value="flip">flip</option>
                                                                <option value="flipInX">flipInX</option>
                                                                <option value="flipInY">flipInY</option>
                                                                <option value="flipOutX">flipOutX</option>
                                                                <option value="flipOutY">flipOutY</option>
                                                            </optgroup>
                                                            <optgroup label="Lightspeed">
                                                                <option value="lightSpeedIn">lightSpeedIn</option>
                                                                <option value="lightSpeedOut">lightSpeedOut</option>
                                                            </optgroup>
                                                            <optgroup label="Rotating Entrances">
                                                                <option value="rotateIn">rotateIn</option>
                                                                <option value="rotateInDownLeft">rotateInDownLeft
                                                                </option>
                                                                <option value="rotateInDownRight">rotateInDownRight
                                                                </option>
                                                                <option value="rotateInUpLeft">rotateInUpLeft</option>
                                                                <option value="rotateInUpRight">rotateInUpRight</option>
                                                            </optgroup>
                                                            <optgroup label="Rotating Exits">
                                                                <option value="rotateOut">rotateOut</option>
                                                                <option value="rotateOutDownLeft">rotateOutDownLeft
                                                                </option>
                                                                <option value="rotateOutDownRight">rotateOutDownRight
                                                                </option>
                                                                <option value="rotateOutUpLeft">rotateOutUpLeft</option>
                                                                <option value="rotateOutUpRight">rotateOutUpRight
                                                                </option>
                                                            </optgroup>
                                                            <optgroup label="Sliding Entrances">
                                                                <option value="slideInUp">slideInUp</option>
                                                                <option value="slideInDown">slideInDown</option>
                                                                <option value="slideInLeft">slideInLeft</option>
                                                                <option value="slideInRight">slideInRight</option>
                                                            </optgroup>
                                                            <optgroup label="Sliding Exits">
                                                                <option value="slideOutUp">slideOutUp</option>
                                                                <option value="slideOutDown">slideOutDown</option>
                                                                <option value="slideOutLeft">slideOutLeft</option>
                                                                <option value="slideOutRight">slideOutRight</option>
                                                            </optgroup>
                                                            <optgroup label="Zoom Entrances">
                                                                <option value="zoomIn">zoomIn</option>
                                                                <option value="zoomInDown">zoomInDown</option>
                                                                <option value="zoomInLeft">zoomInLeft</option>
                                                                <option value="zoomInRight">zoomInRight</option>
                                                                <option value="zoomInUp">zoomInUp</option>
                                                            </optgroup>
                                                            <optgroup label="Zoom Exits">
                                                                <option value="zoomOut">zoomOut</option>
                                                                <option value="zoomOutDown">zoomOutDown</option>
                                                                <option value="zoomOutLeft">zoomOutLeft</option>
                                                                <option value="zoomOutRight">zoomOutRight</option>
                                                                <option value="zoomOutUp">zoomOutUp</option>
                                                            </optgroup>
                                                            <optgroup label="Specials">
                                                                <option value="hinge">hinge</option>
                                                                <option value="rollIn">rollIn</option>
                                                                <option value="rollOut">rollOut</option>
                                                            </optgroup>
                                                        </select>
                                                    </fieldset>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td><p class="qc-opt-title-font"><?php _e('Display floating action button search', 'floating-action-button'); ?> </p>
                                                <div class="cxsc-settings-blocks">
                                                    <fieldset>
                                                        <input id="search" type="checkbox" name="qc_floating_action_button_search"
                                                               value="<?php echo esc_attr('qc_floating_action_button_search', 'floating-action-button'); ?>" <?php echo(get_option('qc_floating_action_button_search') == 'qc_floating_action_button_search' ? 'checked' : ''); ?>>
                                                        <label for="search"><?php _e('Enable floating action button search', 'floating-action-button'); ?></label>
                                                    </fieldset>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td><p class="qc-opt-title-font"> <?php _e('Disable Floating Action Button Icon Animation', 'floating-action-button'); ?> </p>
                                                <div class="cxsc-settings-blocks">
                                                    <input id="qc_fab_floating_action_button_disable_icon_animation" type="checkbox"
                                                           name="qc_fab_floating_action_button_disable_icon_animation"
                                                           value="<?php echo esc_attr('1', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_floating_action_button_disable_icon_animation') == '1' ? 'checked' : ''); ?>>
                                                    <label for="qc_fab_floating_action_button_disable_icon_animation"><?php _e('Disable Floating Action Button Icon Animation for Quick Ball', 'floating-action-button'); ?></label>
                                                </div>
                                            </td>
                                        </tr>
                                       

                                        <tr>
                                            <td><p class="qc-opt-title-font"><strong><?php _e('Override Icon Position', 'floating-action-button'); ?></strong></p>
                                                <div class="cxsc-settings-blocks">
                                                    <?php
                                                    $qc_fab_position_x = get_option('position_x');
                                                    if ((!isset($qc_fab_position_x)) || ($qc_fab_position_x == "")) {
                                                        $qc_fab_position_x = __("0", "floating-action-button");
                                                    }
                                                    $qc_fab_position_y = get_option('position_y');
                                                    if ((!isset($qc_fab_position_y)) || ($qc_fab_position_y == "")) {
                                                        $qc_fab_position_y = __("0", "floating-action-button");
                                                    } ?>
                                                    <p><span class="qc-opt-dcs-font">Offset </span>
                                                        <input type="number" class="qc-opt-dcs-font"
                                                               name="position_x"
                                                               id="position_x"
                                                               value="<?php echo esc_attr($qc_fab_position_x, 'floating-action-button'); ?>"
                                                               placeholder="From Right In px">

                                                        <select class="qc-opt-dcs-font" id="position_x_unit"
                                                                name="position_x_unit">
                                                            <option value="<?php echo esc_attr('px', 'floating-action-button'); ?>" <?php if (get_option('position_x_unit') == 'px') {
                                                                echo 'selected="selected"';
                                                            } ?>>px
                                                            </option>
                                                            <option value="<?php echo esc_attr('percent', 'floating-action-button'); ?>" <?php if (get_option('position_x_unit') == 'percent') {
                                                                echo 'selected="selected"';
                                                            } ?> >Percent (%)
                                                            </option>
                                                        </select>

                                                        <span class="qc-opt-dcs-font"> <?php _e('from Right of the Browser Window', 'floating-action-button'); ?></span>
                                                    </p>
                                                    <p><span class="qc-opt-dcs-font"><?php _e('Offset', 'floating-action-button'); ?> </span>
                                                        <input type="number" class="qc-opt-dcs-font"
                                                               name="position_y"
                                                               id="position_y"
                                                               value="<?php echo  esc_attr($qc_fab_position_y, 'floating-action-button'); ?>"
                                                               placeholder="From Bottom In Px">
                                                        <select class="qc-opt-dcs-font" id="position_y_unit"
                                                                name="position_y_unit">
                                                            <option value="<?php echo esc_attr('px', 'floating-action-button'); ?>" <?php if (get_option('position_y_unit') == 'px') {
                                                                echo 'selected="selected"';
                                                            } ?>>px
                                                            </option>
                                                            <option value="<?php echo esc_attr('percent', 'floating-action-button'); ?>" <?php if (get_option('position_y_unit') == 'percent') {
                                                                echo 'selected="selected"';
                                                            } ?> >Percent (%)
                                                            </option>
                                                        </select>
                                                        <span class="qc-opt-dcs-font"> <?php _e('from Bottom of the Browser Window', 'floating-action-button'); ?></span>
                                                    </p>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>
                                                <p class="qc-opt-title-font"><?php _e('<strong>Floating Action Button</strong> Loading Control Options', 'floating-action-button'); ?></p>

                                                <div class="cxsc-settings-blocks">
                                                    <div class="row">
                                                        <div class="col-sm-4 text-right">
                                                            <span class="qc-opt-title-font"><?php _e('Show on Home Page', 'floating-action-button'); ?></span>

                                                        </div>
                                                        <div class="col-sm-8">
                                                            <label class="radio-inline">
                                                                <input id="qc_fab-show-home-page" type="radio"
                                                                       name="qc_fab_show_home_page"
                                                                       value="<?php echo esc_attr('on', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_home_page') == 'on' ? 'checked' : ''); ?>> YES
                                                            </label>
                                                            <label class="radio-inline">
                                                                <input id="qc_fab-show-home-page" type="radio"
                                                                       name="qc_fab_show_home_page"
                                                                       value="<?php echo esc_attr('off', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_home_page') == 'off' ? 'checked' : ''); ?>> NO
                                                            </label>
                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-sm-4 text-right">
                                                            <span class="qc-opt-title-font"><?php _e('Show on Blog Posts', 'floating-action-button'); ?></span>

                                                        </div>
                                                        <div class="col-sm-8">

                                                            <label class="radio-inline">
                                                                <input class="qc_fab-show-posts" type="radio"
                                                                       name="qc_fab_show_posts"
                                                                       value="<?php echo esc_attr('on', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_posts') == 'on' ? 'checked' : ''); ?>>
                                                                YES
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input class="qc_fab-show-posts" type="radio"
                                                                       name="qc_fab_show_posts"
                                                                       value="<?php echo esc_attr('off', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_posts') == 'off' ? 'checked' : ''); ?>>
                                                                NO
                                                            </label>


                                                        </div>
                                                    </div>
                                                    <div class="row">
                                                        <div class="col-md-4 text-right">
                                                            <span class="qc-opt-title-font"><?php _e('Show on  Pages', 'floating-action-button'); ?></span>

                                                        </div>
                                                        <div class="col-md-8">


                                                            <label class="radio-inline">
                                                                <input class="qc_fab-show-pages" type="radio"
                                                                       name="qc_fab_show_pages"
                                                                       value="<?php echo esc_attr('on', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_pages') == 'on' ? 'checked' : ''); ?>>
                                                                <?php _e('All Pages', 'floating-action-button'); ?>
                                                            </label>

                                                            <label class="radio-inline">
                                                                <input class="qc_fab-show-pages" type="radio"
                                                                       name="qc_fab_show_pages"
                                                                       value="<?php echo esc_attr('off', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_show_pages') == 'off' ? 'checked' : ''); ?>>
                                                                    <?php _e('Selected Pages Only', 'floating-action-button'); ?> </label>

                                                            <div id="qc_fab-show-pages-list">
                                                                <ul class="checkbox-list">
                                                                    <?php
                                                                    $qc_fab_pages = get_pages();
                                                                    $qc_fab_select_pages = unserialize(get_option('qc_fab_show_pages_list'));
                                                                    if(empty($qc_fab_select_pages)){
                                                                        $qc_fab_select_pages = array();
                                                                    }
                                                                    foreach ($qc_fab_pages as $qc_fab_page) {
                                                                        ?>
                                                                        <li>
                                                                            <input id="qc_fab_show_page_<?php echo $qc_fab_page->ID; ?>"
                                                                                   type="checkbox"
                                                                                   name="qc_fab_show_pages_list[]"
                                                                                   value="<?php echo esc_attr($qc_fab_page->ID, 'floating-action-button'); ?>" <?php echo(in_array($qc_fab_page->ID, $qc_fab_select_pages) == true ? 'checked' : ''); ?> >
                                                                            <label for="qc_fab_show_page_<?php echo $qc_fab_page->ID; ?>"> <?php echo $qc_fab_page->post_title; ?></label>
                                                                        </li>
                                                                    <?php } ?>
                                                                </ul>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>
                                        </tbody>
                                    </table>
                                </section>
                                <section id="section-flip-2">
                                    <table class="table table-bordered striped">
                                        <tbody>
                                         <tr>
                                            <td><p class="qc-opt-title-font"> <?php _e('Support Quickball on Floating Action Button', 'floating-action-button'); ?> </p>
                                                <div class="cxsc-settings-blocks">
                                                    <input id="qc_fab_support_quickball" type="checkbox"
                                                           name="qc_fab_support_quickball"
                                                           value="<?php echo esc_attr('qc_fab_support_quickball', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_support_quickball') == 'qc_fab_support_quickball' ? 'checked' : ''); ?>>
                                                    <label for="qc_fab_support_quickball"><?php _e('Enable SUPPORT quickball on
                                                        Floating Action Button', 'floating-action-button'); ?></label>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr id="qc_fab_support_quickball_email_contianer">
                                            <td>
                                                <div>
                                                    <p class="qc-opt-title-font"><?php _e('Support Email Address', 'floating-action-button'); ?></p>
                                                    <?php
                                                    $url = get_site_url();
                                                    $url = parse_url($url);
                                                    $domain = $url['host'];
                                                    $support_email = "support@" . $domain;
                                                    ?>
                                                    <input id="qc_fab_support_quickball_email" class="form-control"
                                                           type="email"
                                                           name="qc_fab_support_quickball_email"
                                                           value="<?php echo(get_option('qc_fab_support_quickball_email') != '' ? get_option('qc_fab_support_quickball_email') : $support_email); ?>">
                                                </div>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td><p class="qc-opt-title-font"> <?php _e('Add A Custom Quickball on Floating Action Button  <span class="badge">Pro version only</span>', 'floating-action-button'); ?></p>
                                                <div class="cxsc-settings-blocks">
                                                    <input id="qc_fab_custom_quickball" type="checkbox" name="qc_fab_custom_quickball"
                                                           value="<?php echo esc_attr('qc_fab_custom_quickball', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_custom_quickball') == 'qc_fab_custom_quickball' ? 'checked' : ''); ?>  disabled="disabled">
                                                    <label for="qc_fab_custom_quickball"><?php _e('Enable custom quickball on
                                                        Floating Action Button', 'floating-action-button'); ?></label>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr id="qc_fab_custom_quickball_link_contianers">
                                            <td>
                                                <div>
                                                    <p class="qc-opt-title-font"><?php _e('Custom Quickball Link <span class="badge">Pro version only</span>', 'floating-action-button'); ?></p>
                                                    <input id="qc_fab_custom_quickball_link" class="form-control" type="text"
                                                           name="qc_fab_custom_quickball_link"
                                                           value="<?php echo(get_option('qc_fab_custom_quickball_link') != '' ? get_option('qc_fab_custom_quickball_link') : site_url()); ?>" disabled="disabled">
                                                </div>
                                            </td>
                                        </tr>

                                        <!-- button nizer -->
                                        
                                        <tr class="">
                                            <td>
                                                <div class="custom_button_div_container">
                                                <ul class="radio-list">
                                                    <li>
                                                        <?php
                                                        if (get_option('qc_fab_custom_quickball_path') != "") {
                                                            $qc_fab_custom_quickball_path = get_option('qc_fab_custom_quickball_path');
                                                        } else {
                                                            $qc_fab_custom_quickball_path = QC_FLOATING_ACTION_BUTTON_IMG_URL . 'custom.png';
                                                        }
                                                        ?>
                                                        <img id="qc_fab_custom_quickball_icon_src"
                                                             src="<?php echo $qc_fab_custom_quickball_path; ?>" alt="">
                                                        <input id="qc_fab_custom_quickball_icon_input" type="radio"
                                                               name="qc_fab_custom_quickball_icon"
                                                               value="<?php echo esc_attr($qc_fab_custom_quickball_path, 'floating-action-button'); ?>" <?php echo($qc_fab_custom_quickball_path!= '' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font"><?php _e('Custom Icon', 'floating-action-button'); ?></span>
                                                    </li>
                                                </ul>
                                               
                                                <div class="col-xs-12">
                                                    <p class="qc-opt-title-font"><?php _e('<strong> Upload Quickball Custom Icon </strong> <span class="badge">Pro version only</span>', 'floating-action-button'); ?></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <input type="hidden" name="qc_fab_custom_quickball_path"
                                                               id="qc_fab_custom_quickball_path"
                                                               value="<?php echo esc_attr($qc_fab_custom_quickball_path, 'floating-action-button'); ?>" disabled="disabled"/>
                                                        <button type="button" class="qc_fab_custom_quickball_icon_button button" disabled="disabled"><?php _e('Upload Icon', 'floating-action-button'); ?>
                                                        </button>
                                                    </div>
                                                </div>
                                            </div>

                                            </td>
                                        </tr>
                                        <tr class="custom_button_add_group qc_fab_custom_quickball_icon_contianers">
                                            <td>
                                                <p class="qc-opt-title-font"><strong> <?php _e('Support more social media platforms', 'floating-action-button'); ?> </strong> </p>
                                                <div class="custom_button_div_container">
                                            <?php

                                            $qc_fab_social_icon_urls  = unserialize( get_option('qc_fab_social_icon_url'));

                                            $qc_fab_social_titles = unserialize( get_option('qc_fab_social_title'));
                                            $qc_fab_social_urls  = unserialize( get_option('qc_fab_social_url'));
                                            $qcld_disable_qc_fab_custom_quickballs  = unserialize( get_option('qcld_disable_qc_fab_custom_quickballs'));

                                            if ($qc_fab_social_titles != '') {

                                                for($i = 0 ; $i<count($qc_fab_social_titles) ; ++$i) {

                                            ?>


                                            <div class="custom_button_div_containers">
                                                <ul class="radio-list">
                                                    <li>
                                                        <img id="qc_fab_custom_quickball_icon_srcs" src="<?php echo $qc_fab_social_icon_urls[$i];  ?>" alt="">
                                                        <input id="qc_fab_custom_quickball_icon_inputs"  type="hidden" 
                                                        name="qc_fab_social_icon_url[]" value="<?php echo esc_attr($qc_fab_social_icon_urls[$i], 'floating-action-button'); ?>" >
                                                        <span class="qc-opt-dcs-font"><?php _e('Custom Icon', 'floating-action-button'); ?></span>
                                                    </li>
                                                </ul>
                                           
                                                <div class="col-xs-12">
                                                    <p class="qc-opt-title-font"><strong> <?php _e('Upload  Quickball Custom Icon', 'floating-action-button'); ?> </strong></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <button type="button" class="qc_fab_custom_quickballs_icon_button button">
                                                        <?php _e('Upload Icon', 'floating-action-button'); ?> </button>
                                                    </div>
                                                </div>
                                                <div class="cxsc-settings-blocks qcld-custom_disabled_quickbox">
                                                    <input id="qcld_disable_qc_fab_custom_quickballs<?php echo $i; ?>" type="checkbox" name="qcld_disable_qc_fab_custom_quickballs[]"
                                                           value="<?php echo esc_attr('enable_qc_fab_custom_quickball', 'floating-action-button'); ?>" <?php if(isset($qcld_disable_qc_fab_custom_quickballs[$i]) && $qcld_disable_qc_fab_custom_quickballs[$i] == 'enable_qc_fab_custom_quickball') { echo 'checked'; } ?>>
                                                    <label for="qcld_disable_qc_fab_custom_quickballs<?php echo $i; ?>">Enable custom quickball on Floating Action Button</label>
                                                </div>
                                                <div class="custom_button_action_control">
                                                        <select name="qc_fab_social_title[]" id="button_type" class="button_action qcld_social_selects">
                                                            <option value="<?php echo esc_attr('url', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'url'){ echo 'selected="selected"'; } ?>>Website URL</option>
                                                            <option value="<?php echo esc_attr('phone', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'phone'){ echo 'selected="selected"'; } ?>>Phone number</option>
                                                            <option value="<?php echo esc_attr('mail', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'mail'){ echo 'selected="selected"'; } ?>>E-mail</option>
                                                            <option value="<?php echo esc_attr('facebook', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'facebook'){ echo 'selected="selected"'; } ?>>Share on Facebook</option>
                                                            <option value="<?php echo esc_attr('twitter', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'twitter'){ echo 'selected="selected"'; } ?>>Share on Twitter</option>
                                                            <option value="<?php echo esc_attr('whatsapp', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'whatsapp'){ echo 'selected="selected"'; } ?>>Share on Whatsapp</option>
                                                            <option value="<?php echo esc_attr('linkedin', 'floating-action-button'); ?>" <?php if($qc_fab_social_titles[$i] == 'linkedin'){ echo 'selected="selected"'; } ?>>Share on Linkedin</option>
                                                        </select>
                                                        <input id="qc_fab_custom_quickball_links" class="form-control custom_buttons_links"
                                                          type="text" name="qc_fab_social_url[]" value="<?php echo esc_attr($qc_fab_social_urls[$i], 'floating-action-button'); ?>">
  
                                                </div>
                                                <button type="button" class="btn btn-warning btn-sm qc_fab-remove-container  pull-right"><i class="fa fa-times" aria-hidden="true"></i></button>
                                            </div>

                                            <?php
                                                }
                                            }
                                            ?>

                                            </div>
                                            
                                                <div class="qc_fab-button-content">
                                                    <button type="button" id="custom_floating_add_new_button_contianer" class="btn btn-info btn-sm pull-right"> <i class="fa fa-plus"></i> <?php _e('Add Custom Icon', 'floating-action-button'); ?> </button>
                                                </div>
                                            </td>
                                        </tr>




                                        </tbody>
                                    </table>
                                </section>
                                <section id="section-flip-3">
                                    <table class="table table-bordered striped">
                                        <tbody>
                                        <tr>
                                            <td><br>
                                                <br>
                                                <ul class="radio-list">
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-0.png"
                                                             alt="">
                                                        <input type="radio"
                                                               name="qc_fab_icon" <?php echo(get_option('qc_fab_icon') == 'icon-0.png' ? 'checked' : ''); ?>
                                                               value="icon-0.png">
                                                        <span class="qc-opt-dcs-font">Icon - 0</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-1.png"
                                                             alt="">
                                                        <input type="radio"
                                                               name="qc_fab_icon" <?php echo(get_option('qc_fab_icon') == 'icon-1.png' ? 'checked' : ''); ?>
                                                               value="icon-1.png">
                                                        <span class="qc-opt-dcs-font">Icon - 1</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-2.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-2.png" <?php echo(get_option('qc_fab_icon') == 'icon-2.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 2</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-3.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-3.png" <?php echo(get_option('qc_fab_icon') == 'icon-3.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 3</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-4.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-4.png" <?php echo(get_option('qc_fab_icon') == 'icon-4.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 4</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-5.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-5.png" <?php echo(get_option('qc_fab_icon') == 'icon-5.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 5</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-6.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-6.png" <?php echo(get_option('qc_fab_icon') == 'icon-6.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 6</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-7.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-7.png" <?php echo(get_option('qc_fab_icon') == 'icon-7.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 7</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-8.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-8.png" <?php echo(get_option('qc_fab_icon') == 'icon-8.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 8</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-9.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-9.png" <?php echo(get_option('qc_fab_icon') == 'icon-9.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon -9</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-10.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-10.png" <?php echo(get_option('qc_fab_icon') == 'icon-10.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 10</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-11.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-11.png" <?php echo(get_option('qc_fab_icon') == 'icon-11.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 11</span></li>
                                                    <li><img src="<?php echo QC_FLOATING_ACTION_BUTTON_IMG_URL; ?>/icon-12.png"
                                                             alt="">
                                                        <input type="radio" name="qc_fab_icon"
                                                               value="icon-12.png" <?php echo(get_option('qc_fab_icon') == 'icon-12.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font">Icon - 12</span></li>
                                                    <li>
                                                        <?php
                                                        if (get_option('qc_fab_custom_icon_path') != "") {
                                                            $qc_fab_custom_icon_path = get_option('qc_fab_custom_icon_path');
                                                        } else {
                                                            $qc_fab_custom_icon_path = QC_FLOATING_ACTION_BUTTON_IMG_URL . 'custom.png';
                                                        }
                                                        ?>
                                                        <img id="qc_fab_custom_icon_src"
                                                             src="<?php echo $qc_fab_custom_icon_path; ?>" alt="">
                                                        <input id="qc_fab_custom_icon_input" type="radio"
                                                               name="qc_fab_icon"
                                                               value="custom.png" <?php echo(get_option('qc_fab_icon') == 'custom.png' ? 'checked' : ''); ?>>
                                                        <span class="qc-opt-dcs-font"><?php _e('Custom Icon', 'floating-action-button'); ?></span>
                                                    </li>
                                                </ul>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>
                                                <!-- <p class="qc-opt-title-font"> Upload custom Icon </p> -->
                                                <div class="col-xs-12">
                                                    <p class="qc-opt-title-font"><strong> <?php _e('Upload custom Icon', 'floating-action-button'); ?> </strong></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <input type="hidden" name="qc_fab_custom_icon_path"
                                                               id="qc_fab_custom_icon_path"
                                                               value="<?php echo esc_attr($qc_fab_custom_icon_path, 'floating-action-button'); ?>"/>
                                                        <button type="button" class="qc_fab_custom_icon_button button"><?php _e('Upload Icon', 'floating-action-button'); ?>
                                                        </button>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>
                                        </tbody>
                                    </table>
                                </section>
                                <section id="section-flip-4">
                                    <p class="qc-opt-dcs-font"><?php _e('Notification Delay Time :', 'floating-action-button'); ?>
                                        <input name="qc_fab_global_notification_delay_time"
                                               type="text"
                                               class="text-control input-sm"
                                               value="<?php echo (get_option('qc_fab_global_notification_delay_time')) ? get_option('qc_fab_global_notification_delay_time') : ''; ?>">
                                        in sec </p>
                                    <hr>
                                    <table class="table table-bordered striped">
                                        <tbody>
                                            <tr>
                                                <td><p class="qc-opt-title-font"> <?php _e('Disable notifications', 'floating-action-button'); ?> </p>
                                                    <div class="cxsc-settings-blocks">
                                                        <input id="qc_floating_action_button_disable_notification" type="checkbox"
                                                               name="qc_floating_action_button_disable_notification"
                                                               value="<?php echo esc_attr('1', 'floating-action-button'); ?>" <?php echo(get_option('qc_floating_action_button_disable_notification') == '1' ? 'checked' : ''); ?>>
                                                        <label for="qc_floating_action_button_disable_notification"><?php _e('Disable front end
                                                            notification', 'floating-action-button'); ?></label>
                                                    </div>
                                                </td>
                                            </tr>
                                            <tr>
                                                <td><p class="qc-opt-title-font"> <?php _e('Disable notifications on mobile devices', 'floating-action-button'); ?> </p>
                                                    <div class="cxsc-settings-blocks">
                                                        <input id="qc_fab_floating_action_button_disable_notification_mobile" type="checkbox"
                                                               name="qc_fab_floating_action_button_disable_notification_mobile"
                                                               value="<?php echo esc_attr('1', 'floating-action-button'); ?>" <?php echo(get_option('qc_fab_floating_action_button_disable_notification_mobile') == '1' ? 'checked' : ''); ?>>
                                                        <label for="qc_fab_floating_action_button_disable_notification_mobile"><?php _e('Disable front end notification', 'floating-action-button'); ?></label>
                                                    </div>
                                                </td>
                                            </tr>
                                            <tr>
                                                <td><p class="qc-opt-title-font"> <?php _e('Repeat pop up notification through out
                                                        user stay on the website <span class="badge">Pro version only</span>', 'floating-action-button'); ?></p>
                                                    <div class="cxsc-settings-blocks">
                                                        <input id="qc_floating_action_button_loop_notification" type="checkbox"
                                                               name="qc_floating_action_button_loop_notification"
                                                               value="<?php echo esc_attr('qc_floating_action_button_loop_notification', 'floating-action-button'); ?>" <?php echo(get_option('qc_floating_action_button_loop_notification') == '1' ? 'checked' : ''); ?> disabled="disabled">
                                                        <label for="qc_floating_action_button_loop_notification"><?php _e('Enable Notification Loop', 'floating-action-button'); ?></label>
                                                    </div>
                                                </td>
                                            </tr>
                                        </tbody>
                                    </table>

                                    <div class="row">
                                        <div class="col-xs-12">
                                            <p class="qc-opt-description"><?php _e('SET NOTIFICATIONS FOR FLOATING ACTION BUTTON', 'floating-action-button'); ?></p>
                                            <div class="cxsc-settings-blockss">
                                                <p>
                                                    <?php $settings = array('textarea_name' =>
                                                        'qc_fab_message_one',
                                                        'textarea_rows' => 20,
                                                        'editor_height' => 80,
                                                        'editor_class' => 'customNotificationClass',
                                                        'disabled' => 'disabled',
                                                        'media_buttons' => false,
                                                        'tinymce' => false,
                                                        'quicktags' => false
                                                    );
                                                    wp_editor(get_option(html_entity_decode(stripcslashes('qc_fab_message_one'))), 'qc_fab_message_one', $settings); ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-xs-12">
                                            <p class="qc-opt-description"></p>
                                            <div class="cxsc-settings-blockss">
                                                <p>
                                                    <?php $settings = array('textarea_name' =>
                                                        'qc_fab_message_two',
                                                        'textarea_rows' => 20,
                                                        'editor_height' => 80,
                                                        'editor_class' => 'customNotificationClass',
                                                        'disabled' => 'disabled',
                                                        'media_buttons' => false,
                                                        'tinymce' => false,
                                                        'quicktags' => false
                                                    );
                                                    wp_editor(get_option(html_entity_decode(stripcslashes('qc_fab_message_two'))), 'qc_fab_message_two', $settings); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                </section>
                             
                                <section id="section-flip-7">
                                    <tr>
                                        <td><p class="qc-opt-title-font"><strong><?php _e('Translate various titles for popup
                                                    view', 'floating-action-button'); ?></strong></p>
                                            <div class="cxsc-settings-blocks">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Global Font Size For Widgets :', 'floating-action-button'); ?>
                                                        <input
                                                                name="qc_fab_global_widget_font_size"
                                                                type="text"
                                                                class="text-control input-sm qc-opt-dcs-font"
                                                                value="<?php echo (get_option('qc_fab_global_widget_font_size')) ? get_option('qc_fab_global_widget_font_size') : ''; ?>">
                                                        in px </p>
                                                </div>
                                            </div>
                                            <br></td>
                                    </tr>
                                    <tr>
                                        <td><p class="qc-opt-title-font"> <?php _e('Rename Search Button Text', 'floating-action-button'); ?> </p>
                                            <div class="cxsc-settings-blocks">
                                                <?php
                                                $qc_fab_button_text = get_option('qc_fab-search-button-text');
                                                if ((!isset($qc_fab_button_text)) || ($qc_fab_button_text == "")) {
                                                    $qc_fab_button_text = __("Find Them!", "floating-action-button");
                                                } ?>
                                                <input type="text" class="qc_fab-search-button-text qc-opt-dcs-font"
                                                       name="qc_fab-search-button-text"
                                                       id="qc_fab-search-button-text"
                                                       value="<?php echo htmlentities($qc_fab_button_text, ENT_QUOTES); ?>">
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td><p class="qc-opt-title-font"> <?php _e('Rename Search Field Placeholder Text', 'floating-action-button'); ?> </p>
                                            <div class="cxsc-settings-blocks">
                                                <input type="text" class="qc_fab-search-button-text qc-opt-dcs-font"
                                                       name="qc_fab_keyword_lang_change"
                                                       id="qc_fab_keyword_lang_change"
                                                       value="<?php echo (get_option('qc_fab_keyword_lang_change')) ? get_option('qc_fab_keyword_lang_change') : 'Keyword ...'; ?>">
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Questions or Comments? Contact Us', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_support_form_title"
                                                           value="<?php echo (get_option('qc_fab_support_form_title')) ? get_option('qc_fab_support_form_title') : 'Questions or Comments? Contact Us'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Full Name', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_support_form_lan_full_name"
                                                           value="<?php echo (get_option('qc_fab_support_form_lan_full_name')) ? get_option('qc_fab_support_form_lan_full_name') : 'Full Name'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Email Address', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_support_form_lan_email_address"
                                                           value="<?php echo (get_option('qc_fab_support_form_lan_email_address')) ? get_option('qc_fab_support_form_lan_email_address') : 'Email Address'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Message', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_support_form_lan_message"
                                                           value="<?php echo (get_option('qc_fab_support_form_lan_message')) ? get_option('qc_fab_support_form_lan_message') : 'Message'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Submit', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_support_form_lan_submit"
                                                           value="<?php echo (get_option('qc_fab_support_form_lan_submit')) ? get_option('qc_fab_support_form_lan_submit') : 'Submit'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <p class="qc-opt-title-font"><strong> <?php _e('Tool Tip Texts', 'floating-action-button'); ?> </strong></p>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Support', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_vertical_support"
                                                           value="<?php echo (get_option('qc_fab_vertical_support')) ? get_option('qc_fab_vertical_support') : 'Support'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Search', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_vertical_search"
                                                           value="<?php echo (get_option('qc_fab_vertical_search')) ? get_option('qc_fab_vertical_search') : 'Search'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"> <?php _e('Custom Link', 'floating-action-button'); ?></p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_vertical_custom"
                                                           value="<?php echo (get_option('qc_fab_vertical_custom')) ? get_option('qc_fab_vertical_custom') : 'Go To'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <div id="qc_fab-ajax-search-message">
                                                <p class="qc-opt-title-font"><strong> <?php _e('Quickball Custom Icon Label', 'floating-action-button'); ?> </strong></p>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('URL', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_url"
                                                           value="<?php echo (get_option('qc_fab_lang_social_url')) ? get_option('qc_fab_lang_social_url') : 'URL'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Phone', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_phone"
                                                           value="<?php echo (get_option('qc_fab_lang_social_phone')) ? get_option('qc_fab_lang_social_phone') : 'Phone'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Mail', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_email"
                                                           value="<?php echo (get_option('qc_fab_lang_social_email')) ? get_option('qc_fab_lang_social_email') : 'Mail'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Facebook', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_facebook"
                                                           value="<?php echo (get_option('qc_fab_lang_social_facebook')) ? get_option('qc_fab_lang_social_facebook') : 'Facebook'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Twitter', 'floating-action-button'); ?> </p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_twitter"
                                                           value="<?php echo (get_option('qc_fab_lang_social_twitter')) ? get_option('qc_fab_lang_social_twitter') : 'Twitter'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Whatsapp', 'floating-action-button'); ?></p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_whatsapp"
                                                           value="<?php echo (get_option('qc_fab_lang_social_whatsapp')) ? get_option('qc_fab_lang_social_whatsapp') : 'Whatsapp'; ?>">
                                                </div>
                                                <div class="form-group">
                                                    <p class="qc-opt-title-font"><?php _e('Linkedin', 'floating-action-button'); ?></p>
                                                    <input type="text" class="form-control qc-opt-dcs-font"
                                                           name="qc_fab_lang_social_linkedin"
                                                           value="<?php echo (get_option('qc_fab_lang_social_linkedin')) ? get_option('qc_fab_lang_social_linkedin') : 'Linkedin'; ?>">
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                </section>
                                <section id="section-flip-8">
                                    <div class="top-section">
                                        <div class="row">
                                            <div class="col-xs-12">
                                                <p class="qc-opt-dcs-font"><?php _e('You can paste or write your custom css
                                                    here.', 'floating-action-button'); ?></p>
                                                <textarea name="qc_fab_custom_global_css"
                                                          class="form-control custom-global-css"
                                                          cols="10"
                                                          rows="15"><?php echo get_option('qc_fab_custom_global_css'); ?></textarea>
                                            </div>
                                        </div>
                                    </div>
                                </section>
                            </div>
                            <!-- /content -->
                        </div>
                        <!-- /tabs-qc-fab -->
                    </section>
                    <div class="row qc_fab-control-panel-footer">
                        <div class="text-left col-sm-3 col-sm-offset-3">
                            <input type="button" class="btn btn-warning submit-button"
                                   id="qc_fab-reset-options-default"
                                   value="<?php _e('Reset all options to Default', 'floating-action-button'); ?>"/>
                        </div>
                        <div class="text-right col-sm-6">
                            <input type="hidden" name="action" value="qc_fab-submitted"/>
                            <input type="submit" class="btn btn-primary submit-button" name="submit"
                                   id="submit" value="<?php _e('Save Settings', 'floating-action-button'); ?>"/>
                        </div>
                    </div>
                </div>
                <?php wp_nonce_field('floating-action-button'); ?>
            </form>
        </div>
        <?php

    }


    /**
     * Save Options
     */

    function floating_action_buttons_save_options()
    {

        // Check if the form is submitted or not

        if (isset($_POST['submit'])) {

            if (isset($_POST["floating_action_button-terms-fields"])) {

                $filter_fields = $_POST["floating_action_button-terms-fields"];
                if ($filter_fields) {
                    $formatted_filter_fields = array();
                    foreach ($filter_fields as $filter_field) {
                        if ($filter_field["filter"] != "") {
                            $formatted_filter_fields[] = stripslashes_deep(array_map("wc_clean", $filter_field));
                        }
                    }
                    $serialized_filter_fields = serialize($formatted_filter_fields);

                    update_option('floating_action_button-terms-fields', $serialized_filter_fields);

                }
            } else {
                if (($_GET["page"] == "floating-action-button") && (isset($_POST["action"]))) {
                    delete_option('floating_action_button-terms-fields');
                }
            }

            if (isset($_POST["qc_fab-search-button-text"])) {
                $button_text = stripslashes(($_POST["qc_fab-search-button-text"]));
                update_option('qc_fab-search-button-text', $button_text);
            }

            if (isset($_POST["qc_fab_keyword_lang_change"])) {
                $qc_fab_keyword_lang_change = stripslashes(($_POST["qc_fab_keyword_lang_change"]));
                update_option('qc_fab_keyword_lang_change', $qc_fab_keyword_lang_change);
            }
            if (isset($_POST["position_x"])) {
                $position_x = sanitize_text_field($_POST["position_x"]);
                update_option('position_x', $position_x);
            }
            if (isset($_POST["position_y"])) {
                $position_y = sanitize_text_field($_POST["position_y"]);
                update_option('position_y', $position_y);
            }
            // position unit
            if (isset($_POST["position_x_unit"])) {
                $position_x_unit = sanitize_text_field(($_POST["position_x_unit"]));
                update_option('position_x_unit', $position_x_unit);
            }
            if (isset($_POST["position_y_unit"])) {
                $position_y_unit = sanitize_text_field(($_POST["position_y_unit"]));
                update_option('position_y_unit', $position_y_unit);
            }

            /**
             * MESSAGE NOTIFICATION DELAY
             */


            if (isset($_POST["qc_floating_action_button_disable"])) {
                update_option('qc_floating_action_button_disable', '');
            }else{
                update_option('qc_floating_action_button_disable', '1');
            }


            //Floating Action Buttons load controlling...
            if (isset($_POST["qc_fab_show_home_page"])) {
                $qc_fab_show_home_page = sanitize_key(($_POST["qc_fab_show_home_page"]));
                update_option('qc_fab_show_home_page', $qc_fab_show_home_page);
            }

            if (isset($_POST["qc_fab_show_posts"])) {
                $qc_fab_show_posts = sanitize_key(($_POST["qc_fab_show_posts"]));
                update_option('qc_fab_show_posts', $qc_fab_show_posts);
            }

            if (isset($_POST["qc_fab_show_pages"])) {
                $qc_fab_show_pages = sanitize_key(($_POST["qc_fab_show_pages"]));
                update_option('qc_fab_show_pages', $qc_fab_show_pages);
            }

            if (isset($_POST["qc_fab_show_pages_list"])) {
                $qc_fab_show_pages_list = $_POST["qc_fab_show_pages_list"];
                update_option('qc_fab_show_pages_list', serialize($qc_fab_show_pages_list));
            }


            if (isset($_POST["qc_floating_action_button_mode"])) {
                $qc_floating_action_button_mode = sanitize_text_field(($_POST["qc_floating_action_button_mode"]));
                update_option('qc_floating_action_button_mode', $qc_floating_action_button_mode);
            }


            if (isset($_POST["qc_fab_floating_action_button_disable_icon_animation"])) {
                $qc_fab_floating_action_button_disable_icon_animation = sanitize_text_field(($_POST["qc_fab_floating_action_button_disable_icon_animation"]));
                update_option('qc_fab_floating_action_button_disable_icon_animation', $qc_fab_floating_action_button_disable_icon_animation);
            }else{
                update_option('qc_fab_floating_action_button_disable_icon_animation', '');

            }
            /**
             * FAKE SALE
             */



            /**
             * FRONT END TITLE
             */

            if (isset($_POST["qc_fab_message_one"])) {
                $button_text = stripslashes(($_POST["qc_fab_message_one"]));
                update_option('qc_fab_message_one', $button_text);
            }
            if (isset($_POST["qc_fab_message_two"])) {
                $button_text = stripslashes(($_POST["qc_fab_message_two"]));
                update_option('qc_fab_message_two', $button_text);
            }


            if (isset($_POST["qc_floating_action_button_form_animation"])) {
                $qc_floating_action_button_form_animation = $_POST['qc_floating_action_button_form_animation'] ? $_POST['qc_floating_action_button_form_animation'] : '';
                update_option('qc_floating_action_button_form_animation', sanitize_text_field($qc_floating_action_button_form_animation));
            }/*else{
                update_option('qc_floating_action_button_form_animation', '');
            }*/


            if (isset($_POST["qc_floating_action_button_search"])) {
                $qc_floating_action_button_search = $_POST['qc_floating_action_button_search'] ? $_POST['qc_floating_action_button_search'] : '';
                update_option('qc_floating_action_button_search', sanitize_text_field($qc_floating_action_button_search));
            }else{
                update_option('qc_floating_action_button_search', '');                    
            }



            if (isset($_POST["qc_floating_action_button_loop_notification"])) {
                $qc_floating_action_button_loop_notification = $_POST['qc_floating_action_button_loop_notification'] ? 1 : '';
                update_option('qc_floating_action_button_loop_notification', sanitize_text_field($qc_floating_action_button_loop_notification));
            }else{
                update_option('qc_floating_action_button_loop_notification', '');
            }

            if (isset($_POST["qc_floating_action_button_disable_notification"])) {
                $qc_floating_action_button_disable_notification = $_POST["qc_floating_action_button_disable_notification"] ? 1 : '';
                update_option('qc_floating_action_button_disable_notification', sanitize_text_field($qc_floating_action_button_disable_notification));
            }else{
                update_option('qc_floating_action_button_disable_notification', '');                    
            }
            if (isset($_POST["qc_fab_floating_action_button_disable_notification_mobile"])) {
                $qc_fab_floating_action_button_disable_notification_mobile = $_POST["qc_fab_floating_action_button_disable_notification_mobile"] ? 1 : '';
                update_option('qc_fab_floating_action_button_disable_notification_mobile', sanitize_text_field($qc_fab_floating_action_button_disable_notification_mobile));
            }else{
                update_option('qc_fab_floating_action_button_disable_notification_mobile', '');
            }

            if (isset($_POST["recommended_products"])) {
                $recommended_products = $_POST['recommended_products'] ? $_POST['recommended_products'] : '';
                update_option('recommended_products', sanitize_text_field($recommended_products));
            }else{
                update_option('recommended_products', '');
            }

            if (isset($_POST["qc_fab_icon"])) {
                $qc_fab_icon = $_POST['qc_fab_icon'] ? $_POST['qc_fab_icon'] : 'icon-1.png';
                update_option('qc_fab_icon', sanitize_text_field($qc_fab_icon));
            }

            if (isset($_POST["last_purchased_product"])) {
                $last_purchased_product = $_POST['last_purchased_product'] ? $_POST['last_purchased_product'] : '';
                update_option('last_purchased_product', sanitize_text_field($last_purchased_product));
            }else{
                update_option('last_purchased_product', '');
            }

            //Support Quickball
            if (isset($_POST["qc_fab_support_quickball"])) {
                $qc_fab_support_quickball = $_POST['qc_fab_support_quickball'] ? $_POST['qc_fab_support_quickball'] : '';
                update_option('qc_fab_support_quickball', esc_html($qc_fab_support_quickball));
            }else{
                update_option('qc_fab_support_quickball', '');
            }
            if (isset($_POST["qc_fab_support_quickball_email"])) {
                $qc_fab_support_quickball_email = $_POST['qc_fab_support_quickball_email'] ? $_POST['qc_fab_support_quickball_email'] : '';
                update_option('qc_fab_support_quickball_email', sanitize_email($qc_fab_support_quickball_email));
            }else{
                update_option('qc_fab_support_quickball_email', '');
            }
            //Custom Quickball
            if (isset($_POST["qc_fab_custom_quickball"])) {
                $qc_fab_custom_quickball = $_POST['qc_fab_custom_quickball'] ? $_POST['qc_fab_custom_quickball'] : '';
                update_option('qc_fab_custom_quickball', esc_html($qc_fab_custom_quickball));
            }else{
                update_option('qc_fab_custom_quickball', '');
            }
            //Custom Quickball
            if (isset($_POST["qc_fab_custom_quickball_icon"])) {
                $qc_fab_custom_quickball_icon = $_POST['qc_fab_custom_quickball_icon'] ? $_POST['qc_fab_custom_quickball_icon'] : '';
                update_option('qc_fab_custom_quickball_icon', esc_html($qc_fab_custom_quickball_icon));
            }else{
                update_option('qc_fab_custom_quickball_icon', '');
            }
            //Custom Quickball Icon Path
            if (isset($_POST["qc_fab_custom_quickball_path"])) {
                $qc_fab_custom_quickball_path = $_POST['qc_fab_custom_quickball_path'];
                update_option('qc_fab_custom_quickball_path', sanitize_text_field($qc_fab_custom_quickball_path));
            }

            if (isset($_POST["qc_fab_custom_quickball_link"])) {
                $qc_fab_custom_quickball_link = $_POST['qc_fab_custom_quickball_link'] ? $_POST['qc_fab_custom_quickball_link'] : '';
                update_option('qc_fab_custom_quickball_link', sanitize_text_field($qc_fab_custom_quickball_link));
            }else{
                update_option('qc_fab_custom_quickball_link', '');
            }



            if (isset($_POST["qcld_disable_qc_fab_custom_quickballs"])) {
                $qcld_disable_qc_fab_custom_quickballs = $_POST['qcld_disable_qc_fab_custom_quickballs'] ? $_POST['qcld_disable_qc_fab_custom_quickballs'] : '';
                update_option('qcld_disable_qc_fab_custom_quickballs', serialize($qcld_disable_qc_fab_custom_quickballs));
            }else{
                update_option('qcld_disable_qc_fab_custom_quickballs', '');
            }

            if (isset($_POST["qc_fab_social_icon_url"])) {
                $qc_fab_social_icon_url = $_POST['qc_fab_social_icon_url'] ? $_POST['qc_fab_social_icon_url'] : '';
                update_option('qc_fab_social_icon_url', serialize($qc_fab_social_icon_url));
            }else{
                update_option('qc_fab_social_icon_url', '');
            }

            if (isset($_POST["qc_fab_social_title"])) {
                $qc_fab_social_title = $_POST['qc_fab_social_title'] ? $_POST['qc_fab_social_title'] : '';
                update_option('qc_fab_social_title', serialize($qc_fab_social_title));
            }else{
                update_option('qc_fab_social_title', '');
            }

            if (isset($_POST["qc_fab_social_url"])) {
                $qc_fab_social_url = $_POST['qc_fab_social_url'] ? $_POST['qc_fab_social_url'] : '';
                update_option('qc_fab_social_url', serialize($qc_fab_social_url));
            }else{
                update_option('qc_fab_social_url', '');
            }

            if (isset($_POST["qc_fab_global_notification_delay_time"])) {
                $qc_fab_global_notification_delay_time = $_POST['qc_fab_global_notification_delay_time'] ? $_POST['qc_fab_global_notification_delay_time'] : '';
                update_option('qc_fab_global_notification_delay_time', sanitize_text_field($qc_fab_global_notification_delay_time));
            }else{
                update_option('qc_fab_global_notification_delay_time', '');
            }
            if (isset($_POST["global_fake_sale_delay_time"])) {
                $global_fake_sale_delay_time = $_POST['global_fake_sale_delay_time'] ? $_POST['global_fake_sale_delay_time'] : '';
                update_option('global_fake_sale_delay_time', sanitize_text_field($global_fake_sale_delay_time));
            }else{
                update_option('global_fake_sale_delay_time', '');
            }

            if (isset($_POST["qc_fab_global_widget_font_size"])) {
                $qc_fab_global_widget_font_size = $_POST['qc_fab_global_widget_font_size'] ? $_POST['qc_fab_global_widget_font_size'] : '';
                update_option('qc_fab_global_widget_font_size', sanitize_text_field($qc_fab_global_widget_font_size));
            }else{
                update_option('qc_fab_global_widget_font_size', '');

            }
            if (isset($_POST["qc_fab_front_tags"])) {
                $grid_data = htmlentities(stripslashes($_POST['qc_fab_front_tags']));
            }


            // upload custom Floating Action Buttons icon
            if (isset($_POST["qc_fab_custom_icon_path"])) {
                $qc_fab_custom_icon_path = $_POST['qc_fab_custom_icon_path'];
                update_option('qc_fab_custom_icon_path', sanitize_text_field($qc_fab_custom_icon_path));
            }
            // upload custom  Floating Action Buttons quickball icon path
            if (isset($_POST["qc_fab_custom_quickball_path"])) {
                $qc_fab_custom_quickball_path = $_POST['qc_fab_custom_quickball_path'];
                update_option('qc_fab_custom_quickball_path', sanitize_text_field($qc_fab_custom_quickball_path));
            }


            //Custom css to over write style.
            if (isset($_POST["qc_fab_custom_global_css"])) {
                $qc_fab_custom_global_css = $_POST["qc_fab_custom_global_css"];
                update_option('qc_fab_custom_global_css', htmlentities(stripslashes($qc_fab_custom_global_css)));
            }

            //Quickball setting

            if (isset($_POST["qc_fab_support_form_title"])) {
                $qc_fab_support_form_title = sanitize_text_field(($_POST["qc_fab_support_form_title"]));
                update_option('qc_fab_support_form_title', $qc_fab_support_form_title);
            }
            if (isset($_POST["qc_fab_support_form_lan_full_name"])) {
                $qc_fab_support_form_lan_full_name = sanitize_text_field(($_POST["qc_fab_support_form_lan_full_name"]));
                update_option('qc_fab_support_form_lan_full_name', $qc_fab_support_form_lan_full_name);
            }
            if (isset($_POST["qc_fab_support_form_lan_email_address"])) {
                $qc_fab_support_form_lan_email_address = sanitize_text_field(($_POST["qc_fab_support_form_lan_email_address"]));
                update_option('qc_fab_support_form_lan_email_address', $qc_fab_support_form_lan_email_address);
            }
            if (isset($_POST["qc_fab_support_form_lan_message"])) {
                $qc_fab_support_form_lan_message = sanitize_text_field(($_POST["qc_fab_support_form_lan_message"]));
                update_option('qc_fab_support_form_lan_message', $qc_fab_support_form_lan_message);
            }
            if (isset($_POST["qc_fab_support_form_lan_submit"])) {
                $qc_fab_support_form_lan_message = sanitize_text_field(($_POST["qc_fab_support_form_lan_submit"]));
                update_option('qc_fab_support_form_lan_submit', $qc_fab_support_form_lan_message);
            }
            // Vertical Settings
            if (isset($_POST["qc_fab_vertical_support"])) {
                $qc_fab_vertical_support = sanitize_text_field(($_POST["qc_fab_vertical_support"]));
                update_option('qc_fab_vertical_support', $qc_fab_vertical_support);
            }
            if (isset($_POST["qc_fab_vertical_search"])) {
                $qc_fab_vertical_search = sanitize_text_field(($_POST["qc_fab_vertical_search"]));
                update_option('qc_fab_vertical_search', $qc_fab_vertical_search);
            }

            if (isset($_POST["qc_fab_vertical_custom"])) {
                $qc_fab_vertical_custom = sanitize_text_field(($_POST["qc_fab_vertical_custom"]));
                update_option('qc_fab_vertical_custom', $qc_fab_vertical_custom);
            }

            if (isset($_POST["qc_fab_lang_social_url"])) {
                $qc_fab_lang_social_url = sanitize_text_field(($_POST["qc_fab_lang_social_url"]));
                update_option('qc_fab_lang_social_url', $qc_fab_lang_social_url);
            }

            if (isset($_POST["qc_fab_lang_social_phone"])) {
                $qc_fab_lang_social_phone = sanitize_text_field(($_POST["qc_fab_lang_social_phone"]));
                update_option('qc_fab_lang_social_phone', $qc_fab_lang_social_phone);
            }

            if (isset($_POST["qc_fab_lang_social_email"])) {
                $qc_fab_lang_social_email = sanitize_text_field(($_POST["qc_fab_lang_social_email"]));
                update_option('qc_fab_lang_social_email', $qc_fab_lang_social_email);
            }

            if (isset($_POST["qc_fab_lang_social_facebook"])) {
                $qc_fab_lang_social_facebook = sanitize_text_field(($_POST["qc_fab_lang_social_facebook"]));
                update_option('qc_fab_lang_social_facebook', $qc_fab_lang_social_facebook);
            }

            if (isset($_POST["qc_fab_lang_social_twitter"])) {
                $qc_fab_lang_social_twitter = sanitize_text_field(($_POST["qc_fab_lang_social_twitter"]));
                update_option('qc_fab_lang_social_twitter', $qc_fab_lang_social_twitter);
            }

            if (isset($_POST["qc_fab_lang_social_whatsapp"])) {
                $qc_fab_lang_social_whatsapp = sanitize_text_field(($_POST["qc_fab_lang_social_whatsapp"]));
                update_option('qc_fab_lang_social_whatsapp', $qc_fab_lang_social_whatsapp);
            }

            if (isset($_POST["qc_fab_lang_social_linkedin"])) {
                $qc_fab_lang_social_linkedin = sanitize_text_field(($_POST["qc_fab_lang_social_linkedin"]));
                update_option('qc_fab_lang_social_linkedin', $qc_fab_lang_social_linkedin);
            }
        }

    }



    function qc_fab_title($title)
    {

        return __("Search Results:", "floating-action-button");
    }



}

/**
 * Instantiate plugin.
 *
 */

if (!function_exists('init_floating_action_buttons')) {
    function init_floating_action_buttons()
    {

        global $wc_floating_action_buttons;

        $wc_floating_action_buttons = WC_FLOATING_ACTION_BUTTONS::get_instance();
    }
}
add_action('plugins_loaded', 'init_floating_action_buttons');


register_activation_hook(__FILE__, 'floating_action_buttons_insert_demo_content');
function floating_action_buttons_insert_demo_content()
{

    $demo_data = array(
    
        0 => array(
            'text' => 'Between Price',
            'filter' => 'price',
            'priceone' => '100',
            'pricetwo' => '500',
            'label' => ''
        )
    );
    if (get_option('qc_fab_icon') == '') {
        update_option('qc_fab_icon', 'icon-0.png');
    }

    if (get_option('floating_action_button-terms-fields') == '') {
        update_option('floating_action_button-terms-fields', serialize($demo_data));
    }

    if (get_option('recommended_products') == '') {
        update_option('recommended_products', 'recommended_products');
    }

    if (get_option('qc_floating_action_button_form_animation') == '') {
        update_option('qc_floating_action_button_form_animation', 'bounce');
    }

    if (get_option('qc_fab_global_notification_delay_time') == '') {
        update_option('qc_fab_global_notification_delay_time', 5);
    }
    if (get_option('global_fake_sale_delay_time') == '') {
        update_option('global_fake_sale_delay_time', 5);
    }
    if (get_option('qc_floating_action_button_mode') == '') {
        update_option('qc_floating_action_button_mode', 'vertical');
    }
    if (get_option('qc_fab_global_widget_font_size') == '') {
        update_option('qc_fab_global_widget_font_size', '20');
    }
    if (get_option('qc_floating_action_button_disable') == '') {
        update_option('qc_floating_action_button_disable', 1);
    }
    if (get_option('qc_fab_keyword_lang_change') == '') {
        update_option('qc_fab_keyword_lang_change', 'Keyword ...');
    }
    if (get_option('qc_fab_floating_action_button_disable_notification_mobile') == '') {
        update_option('qc_fab_floating_action_button_disable_notification_mobile', '');
    }

    if (get_option('fake_sale_notification_sound') == '') {
        update_option('fake_sale_notification_sound', 'fake_sale_notification_sound');
    }
    if (get_option('sell_notification_off_mobile') == '') {
        update_option('sell_notification_off_mobile', 'sell_notification_off_mobile');
    }
    if (get_option('qc_floating_action_button_loop_notification') == '') {
        update_option('qc_floating_action_button_loop_notification', '');
    }
    if (get_option('position_x') == '') {
        update_option('position_x', 50);
    }
    if (get_option('position_y') == '') {
        update_option('position_y', 50);
    }

    if (get_option('position_x_unit') == '') {
        update_option('position_x_unit', 'px');
    }
    if (get_option('position_y_unit') == '') {
        update_option('position_y_unit', 'px');
    }
    if (get_option('qc_fab_message_one') == '') {
        update_option('qc_fab_message_one', "Hi, I am here. What can I help you with today?");
    }
    //Ajax search message settings
    if (get_option('p_scs_msg') != '') {
        update_option('p_scs_msg', 'Great! We have these products.');
    }


    //Quickball settting
    if (get_option('qc_fab_support_form_title') != '') {
        update_option('qc_fab_support_form_title', 'Questions or Comments? Contact Us');
    }
    if (get_option('qc_fab_support_form_lan_full_name') != '') {
        update_option('qc_fab_support_form_lan_full_name', 'Full Name');
    }
    if (get_option('qc_fab_support_form_lan_email_address') != '') {
        update_option('qc_fab_support_form_lan_email_address', 'Email Address');
    }
    if (get_option('qc_fab_support_form_lan_message') != '') {
        update_option('qc_fab_support_form_lan_message', 'Message');
    }
    if (get_option('qc_fab_support_form_lan_submit') != '') {
        update_option('qc_fab_support_form_lan_submit', 'Submit');
    }
    //Vertical Ball settings.
    if (get_option('qc_fab_vertical_support') != '') {
        update_option('qc_fab_vertical_support', 'Support');
    }
    if (get_option('qc_fab_vertical_search') != '') {
        update_option('qc_fab_vertical_search', 'Search');
    }
    if (get_option('qc_fab_vertical_custom') != '') {
        update_option('qc_fab_vertical_custom', 'Go To');
    }
    if (get_option('qc_fab_lang_social_url') != '') {
        update_option('qc_fab_lang_social_url', 'URL');
    }
    if (get_option('qc_fab_lang_social_phone') != '') {
        update_option('qc_fab_lang_social_phone', 'Phone');
    }
    if (get_option('qc_fab_lang_social_email') != '') {
        update_option('qc_fab_lang_social_email', 'Mail');
    }
    if (get_option('qc_fab_lang_social_facebook') != '') {
        update_option('qc_fab_lang_social_facebook', 'Facebook');
    }
    if (get_option('qc_fab_lang_social_twitter') != '') {
        update_option('qc_fab_lang_social_twitter', 'Twitter');
    }
    if (get_option('qc_fab_lang_social_whatsapp') != '') {
        update_option('qc_fab_lang_social_whatsapp', 'Whatsapp');
    }
    if (get_option('qc_fab_lang_social_linkedin') != '') {
        update_option('qc_fab_lang_social_linkedin', 'Linkedin');
    }
    if (get_option('qc_fab_show_home_page') != '') {
        update_option('qc_fab_show_home_page', 'on');
    }
    if (get_option('qc_fab_show_posts') != '') {
        update_option('qc_fab_show_posts', 'on');
    }
    if (get_option('qc_fab_show_pages') != '') {
        update_option('qc_fab_show_pages', 'on');
    }
    if (get_option('qc_fab_custom_icon_path') != '') {
        update_option('qc_fab_custom_icon_path', '');
    }
    if (get_option('qc_fab_show_pages_list') != '') {
        update_option('qc_fab_show_pages_list', serialize(array()));
    }

    //Registrating uninstalling hook
    // register_uninstall_hook(__FILE__, 'qc_fab_delete_all_options_for_uninstall');

}

//
add_action('wp_ajax_qc_fab_delete_all_options_for_uninstall', 'floating_action_buttons_delete_all_options_for_uninstall');
add_action('wp_ajax_nopriv_qc_fab_delete_all_options_for_uninstall', 'floating_action_buttons_delete_all_options_for_uninstall');
//floating action buttons all option will be delete during uninstlling.
function floating_action_buttons_delete_all_options_for_uninstall(){

    delete_option('qc_fab_icon');
    delete_option('floating_action_button-terms-fields');
    delete_option('qc_floating_action_button_disable');
    delete_option('fake_sale_notification_sound');
    delete_option('sell_notification_off_mobile');
    delete_option('position_x');
    delete_option('position_y');
    delete_option('position_x_unit');
    delete_option('position_y_unit');
    delete_option('qc_fab_message_one');
    delete_option('p_scs_msg');
    delete_option('qc_fab-search-button-text');
    delete_option('qc_fab_keyword_lang_change');
    delete_option('qc_floating_action_button_mode');
    delete_option('qc_fab_floating_action_button_disable_icon_animation');
    delete_option('qc_fab_message_one');
    delete_option('qc_fab_message_two');
    delete_option('qc_floating_action_button_form_animation');
    delete_option('fake_sale_notification_sound');
    delete_option('qc_floating_action_button_disable_notification');
    delete_option('qc_fab_floating_action_button_disable_notification_mobile');
    delete_option('qc_floating_action_button_loop_notification');
    delete_option('recommended_products');
    delete_option('last_purchased_product');
    delete_option('qc_fab_custom_quickball');
    delete_option('qc_fab_custom_quickball_link');
    delete_option('qcld_disable_qc_fab_custom_quickballs');
    delete_option('qc_fab_social_icon_url');
    delete_option('qc_fab_social_title');
    delete_option('qc_fab_social_url');
    delete_option('qc_fab_custom_quickball_icon');
    delete_option('qc_fab_global_notification_delay_time');
    delete_option('global_fake_sale_delay_time');
    delete_option('qc_fab_global_widget_font_size');
    delete_option('qc_fab_custom_global_css');
    delete_option('qc_fab_support_form_title');
    delete_option('qc_fab_support_form_lan_full_name');
    delete_option('qc_fab_support_form_lan_email_address');
    delete_option('qc_fab_support_form_lan_message');
    delete_option('qc_fab_support_form_lan_submit');
    delete_option('qc_fab_vertical_support');
    delete_option('qc_fab_vertical_search');
    delete_option('qc_fab_vertical_custom');
    delete_option('qc_fab_lang_social_url');
    delete_option('qc_fab_lang_social_phone');
    delete_option('qc_fab_lang_social_email');
    delete_option('qc_fab_lang_social_facebook');
    delete_option('qc_fab_lang_social_twitter');
    delete_option('qc_fab_lang_social_whatsapp');
    delete_option('qc_fab_lang_social_linkedin');
    delete_option('qc_fab_show_home_page');
    delete_option('qc_fab_show_posts');
    delete_option('qc_fab_show_pages');
    delete_option('qc_fab_show_pages_list');
    delete_option('qc_fab_custom_icon_path');
    floating_action_buttons_insert_demo_content();
    //$html = 'Reset all options to default successfully.';
    $html = __('Reset all options to default successfully.', 'floating-action-button');
    wp_send_json($html);
    wp_die();
}